# -*- coding: utf-8 -*-
#---------------------------------------------------------------------#
# Ice Accumulation Index                                              #
# Filename: icceaccum.py                                              #
# Description: Generates impacts for combined effects if ice and wind #
# Authors: Nathan Foster/Josh Kastman                                 # 
# Created by Nathan Foster (WFO Las Vegas) nathan.foster@noaa.gov     #
# Change Log:                                                         #
# Output for rolling 24 hour periods - Kastman 2018-09-01             #
# Updated for rolling 24 hr output - Kastman 2021-6-28                #
#---------------------------------------------------------------------#

# imports

import arcpy, os, shutil, datetime, time
from datetime import datetime
from time import gmtime, strftime
import logging
import traceback
import glob
from shutil import copyfile
import os.path
from os import path
from arcpy import env
from arcpy.sa import *
import wssi_config as cfg
import wssi_general_functions as gfunc

import sys
#-------#
# Paths #
#-------#

# set up log file

log_stamp = strftime("%Y%m%d%H", gmtime())
logging.basicConfig(filename=cfg.log_dir+'/wssi_log_'+str(log_stamp)+'_ice.log',level=logging.DEBUG, format='%(asctime)s %(message)s', datefmt='%m/%d/%Y %I:%M:%S %p')
from arcpy import env

from arcpy.sa import *
arcpy.env.overwriteOutput = True
arcpy.SetLogHistory(False)

def ice_index():
    arcpy.Delete_management(cfg.in_mem)
    ice_start = strftime("%a, %d %b %Y %H:%M:%S", gmtime())
    #print ("WSSI Ice Start Time "+ice_start)

    #-----------------#
    # Set local lists #
    #-----------------#
    file = cfg.work_dir+'precp_num_list.txt'
    data = open(file, 'r')
    precip_num_text = data.readline()
    precip_num_list = precip_num_text.split()
    
    file = cfg.work_dir+'precip_hrs.txt'
    data = open(file, 'r')
    precip_hrs_txt = data.readline()
    precip_hrs = precip_hrs_txt.split()


    file = cfg.work_dir+'wgust_num_list.txt'
    data = open(file, 'r')
    wgust_num_text = data.readline()
    wgust_num_list = wgust_num_text.split()

    #print wgust_num_list
    
    file = cfg.work_dir+'wgust_hrs.txt'
    data = open(file, 'r')
    wgust_hrs_txt = data.readline()
    wgust_hrs = wgust_hrs_txt.split()

    #print wgust_hrs


    file = cfg.work_dir+'d4wgust_num_list.txt'
    data = open(file, 'r')
    d4wgust_num_text = data.readline()
    d4wgust_num_list = d4wgust_num_text.split()

    file = cfg.work_dir+'d4wgust_hrs.txt'
    data = open(file, 'r')
    d4wgust_hrs_txt = data.readline()
    d4wgust_hrs = d4wgust_hrs_txt.split()

    file = cfg.work_dir+'wgust_max_valid.txt'
    data = open(file, 'r')
    max_vars = data.readline()
    #print max_vars
    
    precip_num_list_d4 = cfg.precip_num_list_d4
    precip_d4_hrs = cfg.precip_d4_hrs
    rdict = cfg.rdict
    rdict_d4 = cfg.rdict_d4

    all_hrs = []
    for hr in precip_hrs:
        all_hrs.append(hr)
    for d4hr in precip_d4_hrs:
        all_hrs.append(d4hr)


    last_gust = wgust_num_list[-1]
    
    wgust_dict = dict(zip(wgust_num_list, wgust_hrs))

    d4wgust_dict = dict(zip(d4wgust_num_list, d4wgust_hrs))

    rlist_6hr = gfunc.rolling_periods(fp = precip_hrs[-1], rHR=4, step=6, hr_list = precip_hrs)
    rlist_nums = gfunc.rolling_periods(fp = precip_num_list[-1], rHR=4, step=6, hr_list = precip_num_list)

    
    #Get Spatial Analyst License
    try:
        if arcpy.CheckExtension("Spatial") == "Available":
            arcpy.CheckOutExtension("Spatial")
        else:
            # Raise a custom exception
            #
            raise LicenseError

    except LicenseError:
        print "Spatial Analyst license is unavailable"  

    print'Starting Ice Accum Index'
    logging.debug ('Starting Ice Accum Index')
    

    wgust_1hr = wgust_num_list[:36]
    wgust_r1h = gfunc.rolling_periods(fp = wgust_1hr[-1], rHR=6, step=1, hr_list = wgust_1hr)
    wgust_1hr_sum = wgust_r1h[::6]

    def wgust_sum(rlist, c):
        
        for r in range (0,len(rlist)):
            ravg = []
            for s in range (0,c):
                ravg.append(cfg.grb_dir+"wgust"+str(rlist[r][s])+".flt")
            ravg_join = ';'.join(ravg)
            #print (ravg_join)
            #print rlist[r][-1]
            arcpy.gp.CellStatistics_sa(ravg_join, cfg.work_dir+"wgust_max_f"+wgust_dict[rlist[r][-1]]+".tif", "MAXIMUM", "DATA")
            print cfg.work_dir+"wgust_max_f"+wgust_dict[rlist[r][-1]]+".tif"
            logging.debug ("wgust max generated for: r: "+cfg.work_dir+"wgust_max_f"+wgust_dict[rlist[r][-1]]+".tif")
            
            
    #cfg.wgust_dict['37']
    #print wgust_1hr_sum
    wgust_sum(rlist = wgust_1hr_sum, c = 6)
    #print wgust_1hr_sum
    
    #print wgust_sum
    #print max_vars
    wgust3hr_list = wgust_num_list[36:int(max_vars)]
    #print wgust3hr_list
    wgust_r3hr_list = gfunc.rolling_periods(fp = wgust3hr_list[-1], rHR=2, step=2, hr_list = wgust3hr_list)
    #print wgust_r3hr_list
    wgust3hr_list_sum = wgust_r3hr_list[::2]
    #print wgust3hr_list_sum
    wgust_sum(rlist = wgust3hr_list_sum, c = 2)

    g = int(max_vars) + 1
    x = 0
    while g <= int(last_gust):
        #print g
        g = g +1
        x = x + 1
        #print cfg.grb_dir+"wgust_d4"+str(x)+".flt"
        #print cfg.work_dir+"wgust_max_f"+d4wgust_dict[str(x)]+".tif"
        arcpy.gp.CellStatistics_sa(cfg.grb_dir+"wgust_d4"+str(x)+".flt", cfg.work_dir+"wgust_max_f"+d4wgust_dict[str(x)]+".tif", "MAXIMUM", "DATA")
        logging.debug ("day 4-7 date used for: "+cfg.work_dir+"wgust_max_f"+d4wgust_dict[str(x)]+".tif")
    ice_list = precip_num_list
    #print ice_list
    
    #urbanfactor = refdir+"urbanfactor.tif"

    for i in ice_list:
        iceaccumhr = cfg.grb_dir+"iceaccum"+str(i)+".flt" 
        wgusthr = cfg.work_dir+"wgust_max_f" + rdict[str(i)] + ".tif"
        windice = cfg.in_mem+"windice" + rdict[str(i)] 
        print 'Creating Ice Accumulation Grid ' + str(i) + "hr "+ rdict[str(i)]
        ## Process: Times (Multiply ice accumulation by 100)
        icecalc = cfg.in_mem+"icecalc" + str(i) 
        arcpy.gp.Times_sa(iceaccumhr, 100, icecalc)
        ## Process: Times (Multiply wind gust grids by ice grid(100))
        icewind = cfg.in_mem+"icewind" + str(i) 
        arcpy.gp.Times_sa(wgusthr, icecalc, icewind)
        ## Process: Reclassify final numbers 
        final = cfg.in_mem+"finalice" + str(i) 
        final_urban = cfg.work_dir+"finalice_" + rdict[str(i)] + ".tif"
        arcpy.gp.Reclassify_sa(icewind, "Value", "0 0.5 0;0.5 200 1;200 300 2;300 375 3;375 500 4;500 625 5;625 875 6;875 1125 7;1125 1300 8;1300 1500 9;1500 12000 10", final, "DATA")
        #arcpy.DefineProjection_management(base_wdir+"finalice" + number + ".tif", "PROJCS['NDFD',GEOGCS['GCS_Unknown',DATUM['D_unknown',SPHEROID['Sphere',6371000.0,0.0]],PRIMEM['Greenwich',0.0],UNIT['Degree',0.0174532925199433]],PROJECTION['Lambert_Conformal_Conic'],PARAMETER['false_easting',0.0],PARAMETER['false_northing',0.0],PARAMETER['central_meridian',-95.0],PARAMETER['standard_parallel_1',25.0],PARAMETER['standard_parallel_2',25.0],PARAMETER['latitude_of_origin',25.0],UNIT['Meter',1.0]]")
        # Process: Times
        arcpy.gp.Times_sa(final, cfg.urbanfactor, final_urban)
        print "final urban created: "+final_urban
        arcpy.Delete_management(windice)
        arcpy.Delete_management(icecalc)
        arcpy.Delete_management(icewind)
        arcpy.Delete_management(final)

    print rlist_6hr
    for r in range (0,len(rlist_6hr)):
        ravg = []
        for s in range (0,4):
            ravg.append(cfg.work_dir+"finalice_"+str(rlist_6hr[r][s])+".tif")
        ravg_join = ';'.join(ravg)
        #print (ravg_join)
        arcpy.gp.CellStatistics_sa(ravg_join, cfg.work_dir+"finalicemax_v"+rlist_6hr[r][-1]+".tif", "MAXIMUM", "DATA")
        #print cfg.work_dir+"finalicemax_v"+rlist_6hr[r][-1]+".tif"
        logging.debug ("Ice finished: "+cfg.work_dir+"finalicemax_v"+rlist_6hr[r][-1]+".tif")

    finIce_list = []
    for file in glob.glob(cfg.work_dir+"*finalicemax_v*"+"*.tif"):
        finIce_list.append(file)
    #print finIce_list
    finIce_join = ';'.join(finIce_list)
    #print finIce_join
    arcpy.gp.CellStatistics_sa(finIce_join, cfg.work_dir+"finalicemax.tif", "MAXIMUM", "DATA")
    #print "total ice: "+cfg.work_dir+"finalicemax.tif"
    logging.debug ("total ice finished: "+cfg.work_dir+"finalicemax.tif")
    arcpy.Delete_management(cfg.in_mem)

    #----------------------------------------------------------------------------------------------------#
    # Copy total, day1 and day2 output to components output folder. Day3 will be coppied in summary step #
    #----------------------------------------------------------------------------------------------------#
    os.chdir(cfg.work_dir)
    if precip_num_list[-1] == str(11):
        d3 = "finalicemax_v66.tif"
    else:
        d3 = "finalicemax_v72.tif"
    infiles = ["finalicemax.tif","finalicemax_v24.tif","finalicemax_v48.tif",d3] #"total_thru_d4_snamt_I.tif""finalicemax_v96.tif",
    outfiles = ["ice_fp.tif","ice_d1.tif","ice_d2.tif","ice_d3.tif"] # "ice_d4fp.tif" "ice_d4.tif",
    for i,o in zip(infiles, outfiles):
        copyfile(cfg.work_dir+i, cfg.comp_out+o)


    rolling_web_list = []
    for file in glob.glob("*finalicemax_v*"+"*.tif"):
        rolling_web_list.append(file)
    #print rolling_web_list

    for f in rolling_web_list:
        rf = 'r24h_IceAccumulation_f'+f[-6:-4]+'.tif'
        copyfile(cfg.work_dir+f, cfg.roll_out+rf)


    ice_end = strftime("%a, %d %b %Y %H:%M:%S", gmtime())
    #print ("WSSI Ice Start Time "+ice_start)
    #print ("WSSI Ice End Time "+ice_end)
    
    print "ice ice baby"
    logging.debug ("ice ice baby")
    logging.debug ("Ice Accumulation Processing Start Time "+ice_start)
    logging.debug ("Ice Accumulation Processing Script Finished "+ice_end)

# Execute Function #
ice_index()
logging.shutdown()
